@@ -26,7 +26,7 @@ MYSQL_USER_EXISTS = "SHOW GRANTS FOR '%(db_user)s'@localhost"
 
 def _get_root_password():
     """Ask root password only once if needed"""
-    if env.conf.DB_ROOT_PASSWORD is None:
+    if env.conf.get('DB_ROOT_PASSWORD', None) is None:
         env.conf.DB_ROOT_PASSWORD = prompt('Please enter MySQL root password:')
     return env.conf.DB_ROOT_PASSWORD
 
